# -*- coding: utf-8 -*-
#
# Author: Rodney Dawes <rodney.dawes@canonical.com>
#
# Copyright 2009 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
""" Tests for the changeup-dispatcher script """

import new
import os

from contrib.mocker import Mocker, MockerTestCase

class DispatcherTests(MockerTestCase):
    """Basic tests for the ubuntuone-login script """

    _path = os.path.join(os.getcwd(), "changeup-dispatcher")
    _dispatcher = new.module('dispatcher')
    execfile(_path, _dispatcher.__dict__)

    _mocker = Mocker()
    _dispatcher.dbus = _mocker.mock()
    _dispatcher.dbus.service.signal = _mocker.mock()

    class FakeDispatcher(_dispatcher.Dispatcher):
        def RestartDispatched(self, appname):
            pass

    def setUp(self):
        MockerTestCase.setUp(self)
        self.dispatcher = self.FakeDispatcher()

    def test_queue_restart(self):
        """ Test that getting an error works correctly. """
        self.expect(self.dispatcher.queue.append('changeup'))
        self.dispatcher.queue_restart('changeup')
        self.mocker.replay()

    def test_dispatch_requests(self):
        self.expect(self.dispatcher.queue.append('changeup'))
        self.expect(self.dispatcher.queue.append('dispatcher'))
        self.dispatcher.queue_restart('changeup')
        self.dispatcher.queue_restart('dispatcher')
        self.expect(self.dispatcher.RestartDispatched('changeup'))
        self.expect(self.dispatcher.queue.remove('changeup'))
        self.expect(self.dispatcher.RestartDispatched('dispatcher'))
        self.expect(self.dispatcher.queue.remove('dispatcher'))
        self.dispatcher.dispatch_requests()
        self.mocker.replay()
